@@ -14,7 +14,7 @@
 #'
 #' @param facet the facet(s) for which to retrieve valid values. Can be one or
 #' more of:
-#'  `"license_id", "download_audience", "type", "res_format", "sector", "organization"`
+#'  `"license_id", "download_audience", "type", "res_format", "sector", "organization", "groups"`
 #'
 #' @return A data frame of values for the selected facet
 #' @export
@@ -27,7 +27,7 @@
 #' }
 bcdc_search_facets <- function(facet = c("license_id", "download_audience",
                                   "type", "res_format", "sector",
-                                  "organization")) {
+                                  "organization", "groups")) {
   if(!has_internet()) stop("No access to internet", call. = FALSE) # nocov
 
   facet <- match.arg(facet, several.ok = TRUE)
@@ -54,6 +54,39 @@ bcdc_search_facets <- function(facet = c("license_id", "download_audience",
 
 }
 
+#' @export
+#' @describeIn bcdc_list_group_records
+#'
+bcdc_list_groups <- function() bcdc_search_facets("groups")
+
+#' Retrieve group information for B.C. Data Catalogue
+#'
+#' Returns a tibble of groups or records. Groups can be viewed here:
+#' https://catalogue.data.gov.bc.ca/group or accessed directly from R using `bcdc_list_groups`
+#'
+#' @param group Name of the group
+#' @export
+#' @examples
+#' \donttest{
+#' bcdc_list_group_records('environmental-reporting-bc')
+#' }
+
+bcdc_list_group_records <- function(group) {
+  if(!has_internet()) stop("No access to internet", call. = FALSE) # nocov
+
+  cli <- bcdc_catalogue_client("action/group_show")
+
+  r <- cli$get(query = list(id = group, include_datasets = 'true'))
+  r$raise_for_status()
+
+  res <- jsonlite::fromJSON(r$parse("UTF-8"))
+  stopifnot(res$success)
+
+  d <- tibble::as_tibble(res$result$packages)
+  as.bcdc_group(d, description = res$result$description)
+
+}
+
 #' Return a full list of the names of B.C. Data Catalogue records
 #'
 #' @return A character vector of the names of B.C. Data Catalogue records
@@ -259,6 +292,12 @@ as.bcdc_recordlist <- function(x) {
   x
 }
 
+as.bcdc_group <- function(x, description) {
+  structure(x,
+            class = c("bcdc_group", setdiff(class(x), "bcdc_group")),
+            description = description)
+}
+
 
 #' Provide a data frame containing the metadata for all resources from a single B.C. Data Catalogue record
 #'
